@@ -105,6 +105,8 @@ class Gui:
 	### BACKUP PAGE ###
 	def on_treeview_backup_sets_cursor_changed(self, widget):
 		tree, itera = widget.get_selection().get_selected()
+		if itera is None:
+			return
 		selected = tree.get_value(itera, 2)
 		self.widgets.get_widget('label_backup_set_info').set_text(selected.desc)
 		self.widgets.get_widget('label_backup_set_title').set_markup("<big><b>"+selected.name+"</b></big>")
@@ -500,10 +502,10 @@ class Gui:
 			sys.stdout = sys.__stdout__
 			sys.stderr = sys.__stderr__
 			if len(stderror) > 0:
-				self.statuswin.addmsg(_("An error occurred whilst backing up '%s'.") % bset['name'])
+				self.statuswin.addmsg(_("An error occurred whilst backing up '%s'.") % bset.name)
 				self.statuswin.show()
 			else:
-				self.dialogs.showerror(_("An error occurred whilst backing up '%s'.") % bset['name'])
+				self.dialogs.showerror(_("An error occurred whilst backing up '%s'.") % bset.name)
 			self.statuswin.addmsg(_("Backup failed (rdiff-backup failed)\n%s") % tb)
 		self.widgets.get_widget('lbl_status').set_text(_("Ready."))
 		self.widgets.get_widget('progressbar1').set_fraction(0)
@@ -669,7 +671,7 @@ class Gui:
 			self.widgets.get_widget('lbl_restore_desc').set_text(bset['desc'])
 			self.widgets.get_widget('cmb_restore_increment').set_model(bset['increments'])
 			self.widgets.get_widget('cmb_restore_increment').set_active(0)
-			if set.has_key('readonly'):
+			if bset.has_key('readonly'):
 				#self.widgets.get_widget('read_only_source').show()
 				self.read_only_source = True
 			else:
@@ -886,8 +888,18 @@ class Gui:
 		if response == gtk.RESPONSE_YES:
 			# user is totally sure they want to delete, so let's do it
 			widget.destroy()
-			shutil.rmtree(path)
-			func() # go back to where we came from
+			try:
+				shutil.rmtree(path)
+			except OSError, e:
+				self.dialogs.showerror(
+					_("Could not remove '%(filename)s': "
+					  "%(error_msg)s") %\
+						{'filename': e.filename,
+						'error_msg': e.strerror})
+				self.statuswin.addmsg(_("Operation failed.\n"))
+				return
+
+			func(None) # go back to where we came from
 		else:
 			self.statuswin.addmsg(_("Restore aborted, no files were changed.\n"))
 			widget.destroy()
